=======
Testing
=======

Testing is set to evaluate:

- style with `flake8 <https://pypi.org/project/flake8/>`_,
- typing with `mypy <https://pypi.org/project/mypy/>`_,
- valid function return values and behaviors with `hypothesis <https://pypi.org/project/hypothesis/>`_, and
- test coverage using `coverage <https://pypi.org/project/coverage/>`_.

Windows
-------

Run ``test.bat`` in the ``test`` directory.


Linux
-----

Run ``test.sh`` in the ``test`` directory.
